@@ -1,4 +1,4 @@
-from watchmen_pipeline_kernel.boot import init_prebuilt_external_writers
+from watchmen_pipeline_kernel.boot import init_prebuilt_external_writers, init_topic_snapshot_jobs
 from .connectors import init_kafka, init_rabbitmq
 from .settings import ask_kafka_connector_enabled, ask_kafka_connector_settings, ask_rabbitmq_connector_enabled, \
 	ask_rabbitmq_connector_settings
@@ -26,5 +26,14 @@ class PipelineSurface:
 	def init_external_writers(self) -> None:
 		init_prebuilt_external_writers()
 
+	# noinspection PyMethodMayBeStatic
+	def init_topic_snapshot_jobs(self) -> None:
+		init_topic_snapshot_jobs()
+
+	def init(self) -> None:
+		self.init_connectors()
+		self.init_external_writers()
+		self.init_topic_snapshot_jobs()
+
 
 pipeline_surface = PipelineSurface()
